import time
import numpy as np
import pandas as pd
from sklearn.datasets import fetch_openml
from sklearn.decomposition import PCA
from sklearn.manifold import TSNE
import matplotlib.pyplot as plt
import seaborn as sns

mnist = fetch_openml('Fashion-MNIST') #or MNIST_784
X = mnist.data / 255.0
Y = mnist.target


sns.set_style('darkgrid')
sns.set_palette('muted')
sns.set_context("notebook", font_scale=1.5, rc={"lines.linewidth": 2.5})
RS = 123

x_subset = X[:10000]
y_subset = Y[:10000]

time_start = time.time()

pca_50 = PCA(n_components=50)
pca_result_50 = pca_50.fit_transform(x_subset)

#print('PCA with 50 components done! Time elapsed: {} seconds'.format(time.time()-time_start))
#print('Cumulative variance explained by 50 principal components: {}'.format(np.sum(pca_50.explained_variance_ratio_)))

time_start = time.time()

pca_tsne = TSNE(random_state=RS).fit_transform(pca_result_50)

tsne_df = pd.DataFrame({'X':pca_tsne[:,0], 'Y':pca_tsne[:,1], 'digit':y_subset})

#print('t-SNE done! Time elapsed: {} seconds'.format(time.time()-time_start))
sns.scatterplot(x='X', y='Y', hue="digit", palette=['purple','red','orange','brown','blue', 'dodgerblue','green','lightgreen','darkcyan', 'black'],
              legend='full', linewidth=0, alpha=0.8, data=tsne_df);

plt.title('t-SNE: Fashion-MNIST', weight='bold').set_fontsize('14') #MNIST(numbers)

plt.show()
